class MarketProduct {
  int? id;
  String? reference;
  String? pictureUrl;
  int? categoryId;
  int? purchaseType;
  int? warrantyDuration;
  int? planDuration;
  int? workDuration;
  int? numberOfItems;
  String? label;
  String? languageCode;
  String? subtitleLabel;
  String? description;
  Map? jsonDescription;
  String? countryCode;
  double? price;
  double? priceMonthly;
  double? priceYearly;
  String? currency;
  double? currentDiscountActive;
  double? currentDiscountInPercent;
  double? discountBetweenYearAndMonth;
  ConvertedPricing? convertedPricing;

  MarketProduct(
      {this.id,
      this.reference,
      this.pictureUrl,
      this.categoryId,
      this.purchaseType,
      this.warrantyDuration,
      this.planDuration,
      this.workDuration,
      this.numberOfItems,
      this.label,
      this.languageCode,
      this.subtitleLabel,
      this.description,
      this.jsonDescription,
      this.countryCode,
      this.price,
      this.priceMonthly,
      this.priceYearly,
      this.currency,
      this.currentDiscountActive,
      this.currentDiscountInPercent,
      this.discountBetweenYearAndMonth,
      this.convertedPricing});

  MarketProduct.fromJson(Map<String, dynamic> json) {
    reference = json["reference"];
    pictureUrl = json["pictureUrl"];
    id = json["id"];
    categoryId = json["categoryId"];
    purchaseType = json["purchaseType"];
    warrantyDuration = json["warrantyDuration"];
    planDuration = json["planDuration"];
    workDuration = json["workDuration"];
    numberOfItems = json["numberOfItems"];
    label = json["label"];
    languageCode = json["languageCode"];
    subtitleLabel = json["subtitleLabel"];
    description = json["description"];
    jsonDescription = json["jsonDescription"];
    countryCode = json["countryCode"];
    price = json["price"];
    priceMonthly = json["priceMonthly"];
    priceYearly = json["priceYearly"];
    currency = json["currency"];
    currentDiscountActive = json["currentDiscountActive"];
    currentDiscountInPercent = json["currentDiscountInPercent"];
    discountBetweenYearAndMonth = json["discountBetweenYearAndMonth"];
    convertedPricing = json["convertedPricing"] == null
        ? null
        : ConvertedPricing.fromJson(json["convertedPricing"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["reference"] = reference;
    _data["pictureUrl"] = pictureUrl;
    _data["id"] = id;
    _data["categoryId"] = categoryId;
    _data["purchaseType"] = purchaseType;
    _data["warrantyDuration"] = warrantyDuration;
    _data["planDuration"] = planDuration;
    _data["workDuration"] = workDuration;
    _data["numberOfItems"] = numberOfItems;
    _data["label"] = label;
    _data["languageCode"] = languageCode;
    _data["subtitleLabel"] = subtitleLabel;
    _data["description"] = description;
    if (jsonDescription != null) {
      _data["jsonDescription"] = jsonDescription;
    }
    _data["countryCode"] = countryCode;
    _data["price"] = price;
    _data["priceMonthly"] = priceMonthly;
    _data["priceYearly"] = priceYearly;
    _data["currency"] = currency;
    _data["currentDiscountActive"] = currentDiscountActive;
    _data["currentDiscountInPercent"] = currentDiscountInPercent;
    _data["discountBetweenYearAndMonth"] = discountBetweenYearAndMonth;
    if (convertedPricing != null) {
      _data["convertedPricing"] = convertedPricing?.toJson();
    }
    return _data;
  }

  MarketProduct copyWith({
    String? reference,
    String? pictureUrl,
    int? id,
    int? categoryId,
    int? purchaseType,
    int? warrantyDuration,
    int? planDuration,
    int? workDuration,
    int? numberOfItems,
    String? label,
    String? languageCode,
    String? subtitleLabel,
    String? description,
    Map? jsonDescription,
    String? countryCode,
    double? price,
    double? priceMonthly,
    double? priceYearly,
    String? currency,
    double? currentDiscountActive,
    double? currentDiscountInPercent,
    double? discountBetweenYearAndMonth,
    ConvertedPricing? convertedPricing,
  }) =>
      MarketProduct(
        reference: reference ?? this.reference,
        pictureUrl: pictureUrl ?? this.pictureUrl,
        id: id ?? this.id,
        categoryId: categoryId ?? this.categoryId,
        purchaseType: purchaseType ?? this.purchaseType,
        warrantyDuration: warrantyDuration ?? this.warrantyDuration,
        planDuration: planDuration ?? this.planDuration,
        workDuration: workDuration ?? this.workDuration,
        numberOfItems: numberOfItems ?? this.numberOfItems,
        label: label ?? this.label,
        languageCode: languageCode ?? this.languageCode,
        subtitleLabel: subtitleLabel ?? this.subtitleLabel,
        description: description ?? this.description,
        jsonDescription: jsonDescription ?? this.jsonDescription,
        countryCode: countryCode ?? this.countryCode,
        price: price ?? this.price,
        priceMonthly: priceMonthly ?? this.priceMonthly,
        priceYearly: priceYearly ?? this.priceYearly,
        currency: currency ?? this.currency,
        currentDiscountActive:
            currentDiscountActive ?? this.currentDiscountActive,
        currentDiscountInPercent:
            currentDiscountInPercent ?? this.currentDiscountInPercent,
        discountBetweenYearAndMonth:
            discountBetweenYearAndMonth ?? this.discountBetweenYearAndMonth,
        convertedPricing: convertedPricing ?? this.convertedPricing,
      );
}

class ConvertedPricing {
  double? price;
  double? priceMonthly;
  double? priceYearly;
  String? currency;

  ConvertedPricing(
      {this.price, this.priceMonthly, this.priceYearly, this.currency});

  ConvertedPricing.fromJson(Map<String, dynamic> json) {
    price = json["price"];
    priceMonthly = json["priceMonthly"];
    priceYearly = json["priceYearly"];
    currency = json["currency"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["price"] = price;
    _data["priceMonthly"] = priceMonthly;
    _data["priceYearly"] = priceYearly;
    _data["currency"] = currency;
    return _data;
  }

  ConvertedPricing copyWith({
    double? price,
    double? priceMonthly,
    double? priceYearly,
    String? currency,
  }) =>
      ConvertedPricing(
        price: price ?? this.price,
        priceMonthly: priceMonthly ?? this.priceMonthly,
        priceYearly: priceYearly ?? this.priceYearly,
        currency: currency ?? this.currency,
      );
}
